from openai import OpenAI
from config import SYSTEM_PROMPT, OPEN_API_KEY, SUPABASE_KEY, SUPABASE_URL
from supabase import create_client, Client
from text_processing import fuzzy_correct_chinese
import csv

client = OpenAI(api_key=OPEN_API_KEY)
supabase: Client = create_client(SUPABASE_URL, SUPABASE_KEY)

def load_custom_vocab_from_csv(file_path):
    custom_vocab = []
    try:
        with open(file_path, 'r', encoding='utf-8') as csvfile:
            reader = csv.DictReader(csvfile)
            custom_vocab = [row['brand'] for row in reader if 'brand' in row]
    except Exception as e:
        print(f"Error reading CSV file: {str(e)}")
        print("Using empty vocabulary.")
    return custom_vocab

def transcribe(audio_file):
    try:
        custom_vocab = load_custom_vocab_from_csv('brand_database_rows.csv')
        
        transcript = client.audio.transcriptions.create(
            file=audio_file,
            model="whisper-1",
            response_format="text", 
            prompt=f"請注意以下詞彙：{custom_vocab}"
        )
        return transcript
    except Exception as e:
        print(f"轉錄時發生錯誤：{str(e)}")
        return None

def post_process_transcript(transcript, temperature=0):
    corrected_transcript = fuzzy_correct_chinese(transcript)
    
    messages = [
        {"role": "system", "content": SYSTEM_PROMPT},
        {"role": "user", "content": f"請校對並修正以下轉錄文本，但不要改變其原意或回答問題，也不要更動英文的大小寫：\n\n{corrected_transcript}"}
    ]

    response = client.chat.completions.create(
        model="gpt-4",
        temperature=temperature,
        messages=messages
    )

    return response.choices[0].message.content

def process_audio(audio_data):
    raw_transcript = transcribe(audio_data)
    print(raw_transcript)
    if raw_transcript is None:
        return None, None
    corrected_transcript = post_process_transcript(raw_transcript)
    return raw_transcript, corrected_transcript