import sys
from dictionary_loader import load_word_database_dictionary_from_supabase
from audio_processing import process_audio

def initialize():
    word_database_success = load_word_database_dictionary_from_supabase()
    if not word_database_success:
        print("Warning: Word Database Dictionary loading failed. Proceeding with default dictionary.")


def process_audio_file(audio_file):
    try:
        result = process_audio(audio_file)
        if isinstance(result, tuple) and len(result) == 2:
            return result
        else:
            print("Unexpected result from process_audio")
            return None, None
    except Exception as e:
        print(f"Error processing audio: {str(e)}")
        return None, None
    
# 加入檢查user是否詢問特定問題
def main(audio_file_path):
    initialize()
    try:
        with open(audio_file_path, "rb") as audio_file:
            raw_transcript, corrected_transcript = process_audio_file(audio_file)
        
        if raw_transcript and corrected_transcript:
            print(f"Raw transcript: {raw_transcript}")
            print(f"Corrected transcript: {corrected_transcript}")
            
        else:
            print("Audio processing failed.")
    except FileNotFoundError:
        print(f"Error: The file '{audio_file_path}' was not found.")
    except Exception as e:
        print(f"An unexpected error occurred: {str(e)}")
        import traceback
        traceback.print_exc()


## 原本的main
# def main(audio_file_path):
#     initialize()
#     try:
#         with open(audio_file_path, "rb") as audio_file:
#             result = process_audio_file(audio_file)
        
#         if result:
#             print(result)
#         else:
#             print("Audio processing failed.")
#     except FileNotFoundError:
#         print(f"Error: The file '{audio_file_path}' was not found.")
#     except Exception as e:
#         print(f"An unexpected error occurred: {str(e)}")


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Usage: python script_name.py <audio_file_path>")
        sys.exit(1)
    
    audio_file_path = sys.argv[1]
    main(audio_file_path)